'use client';
import clsx from 'clsx';
import { useCallback } from 'react';
import { useStore } from 'zustand';
import { OpenAPISelect, OpenAPISelectItem } from './OpenAPISelect';
import { getOrCreateStoreByKey } from './getOrCreateStoreByKey';
function useMediaTypeState(data, defaultKey) {
    var method = data.method, path = data.path;
    var store = useStore(getOrCreateStoreByKey("media-type-".concat(method, "-").concat(path), defaultKey));
    if (typeof store.key !== 'string') {
        throw new Error('Media type key is not a string');
    }
    return {
        mediaType: store.key,
        setMediaType: useCallback(function (index) { return store.setKey(index); }, [store.setKey]),
    };
}
function useMediaTypeSampleIndexState(data, mediaType) {
    var method = data.method, path = data.path;
    var store = useStore(getOrCreateStoreByKey("media-type-sample-".concat(mediaType, "-").concat(method, "-").concat(path), 0));
    if (typeof store.key !== 'number') {
        throw new Error('Example key is not a number');
    }
    return {
        index: store.key,
        setIndex: useCallback(function (index) { return store.setKey(index); }, [store.setKey]),
    };
}
export function OpenAPIMediaTypeExamplesSelector(props) {
    var method = props.method, path = props.path, renderers = props.renderers;
    if (!renderers[0]) {
        throw new Error('No renderers provided');
    }
    var state = useMediaTypeState({ method: method, path: path }, renderers[0].mediaType);
    var selected = renderers.find(function (r) { return r.mediaType === state.mediaType; }) || renderers[0];
    return (<div className="openapi-codesample-selectors">
            <MediaTypeSelector state={state} renderers={renderers}/>
            <ExamplesSelector method={method} path={path} renderer={selected}/>
        </div>);
}
function MediaTypeSelector(props) {
    var renderers = props.renderers, state = props.state;
    if (renderers.length < 2) {
        return null;
    }
    var items = renderers.map(function (renderer) { return ({
        key: renderer.mediaType,
        label: renderer.mediaType,
    }); });
    return (<OpenAPISelect className={clsx('openapi-select')} selectedKey={state.mediaType} items={renderers.map(function (renderer) { return ({
            key: renderer.mediaType,
            label: renderer.mediaType,
        }); })} onSelectionChange={function (e) { return state.setMediaType(String(e)); }} placement="bottom start">
            {items.map(function (item) { return (<OpenAPISelectItem key={item.key} id={item.key} value={item}>
                    {item.label}
                </OpenAPISelectItem>); })}
        </OpenAPISelect>);
}
function ExamplesSelector(props) {
    var method = props.method, path = props.path, renderer = props.renderer;
    var state = useMediaTypeSampleIndexState({ method: method, path: path }, renderer.mediaType);
    if (renderer.examples.length < 2) {
        return null;
    }
    var items = renderer.examples.map(function (example, index) { return ({
        key: index,
        label: example.example.summary || "Example ".concat(index + 1),
    }); });
    return (<OpenAPISelect items={items} selectedKey={state.index} onSelectionChange={function (e) { return state.setIndex(Number(e)); }} placement="bottom start">
            {items.map(function (item) { return (<OpenAPISelectItem key={item.key} id={item.key} value={item}>
                    {item.label}
                </OpenAPISelectItem>); })}
        </OpenAPISelect>);
}
export function OpenAPIMediaTypeExamplesBody(props) {
    var _a;
    var renderers = props.renderers, method = props.method, path = props.path;
    if (!renderers[0]) {
        throw new Error('No renderers provided');
    }
    var mediaTypeState = useMediaTypeState({ method: method, path: path }, renderers[0].mediaType);
    var selected = (_a = renderers.find(function (r) { return r.mediaType === mediaTypeState.mediaType; })) !== null && _a !== void 0 ? _a : renderers[0];
    if (selected.examples.length === 0) {
        return selected.element;
    }
    return <ExamplesBody method={method} path={path} renderer={selected}/>;
}
function ExamplesBody(props) {
    var _a;
    var method = props.method, path = props.path, renderer = props.renderer;
    var exampleState = useMediaTypeSampleIndexState({ method: method, path: path }, renderer.mediaType);
    var example = (_a = renderer.examples[exampleState.index]) !== null && _a !== void 0 ? _a : renderer.examples[0];
    if (!example) {
        throw new Error("No example found for index ".concat(exampleState.index));
    }
    return example.element;
}
